
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.1.42'
version = '1.1.42'
full_version = '1.1.42'
git_revision = 'd9c08c74e0f1f078d78bb37ed4646de87af9c201'
release = True

if not release:
    version = full_version
    short_version += ".dev"
